@@ -1,11 +1,8 @@
-import os
+"""Doc string."""
 import sys
-import pycifstar
 
 from cryspy_editor.main_window import main_w
 
-
-
 l_argv = sys.argv
 flag = True
 
@@ -14,4 +11,4 @@ if flag:
     main_w(l_argv)
 else:
     pass
-print("That's all")
\ No newline at end of file
+print("That's all")
