@@ -301,14 +301,14 @@ class CBuilder(QtWidgets.QMainWindow):
         open_folder.triggered.connect(self.open_folder)
         self.toolbar.addAction(open_folder)
 
-        fileMenu = menubar.addMenu('&Object manipulations')
-        manip_action = QtWidgets.QAction('Switch to global', fileMenu)
+        fileMenu = menubar.addMenu('&Calculations')
+        manip_action = QtWidgets.QAction('Global', fileMenu)
         manip_action.object = GlobalN
         manip_action.triggered.connect(self.transfer)
         fileMenu.addAction(manip_action)
         for item_cls in L_GLOBAL_CLS:
             manip_action = QtWidgets.QAction(
-                f'Switch to {item_cls.PREFIX:}', fileMenu)
+                f'{item_cls.PREFIX.capitalize():}', fileMenu)
             manip_action.object = item_cls
             manip_action.triggered.connect(self.transfer)
             fileMenu.addAction(manip_action)
@@ -564,7 +564,8 @@ To upgrade see the site: \n\
         with open(f_setup, "w") as fid:
             fid.write(s_cont)
 
-    @QtCore.pyqtSlot(QtWidgets.QTreeWidgetItem, QtWidgets.QTreeWidgetItem)
+    # @QtCore.pyqtSlot(QtWidgets.QTreeWidgetItem, QtWidgets.QTreeWidgetItem)
+    @QtCore.pyqtSlot(QtWidgets.QTreeWidgetItem, int)
     def onItemClicked(self, it, col):
         """On item clicked."""
         if it is not None:
