@@ -6,7 +6,7 @@ try:
     flag_web_engine = True
 except:
     flag_web_engine = False
-flag_web_engine = False
+
 
 from cryspy import LoopN, ItemN
 
@@ -72,6 +72,7 @@ class WBaseObj(QtWidgets.QTabWidget):
         for ind_item in range(self.count()-1, -1, -1):
             self.removeTab(ind_item)
         plt.close()
+        plt.close()
 
         # Interactive tab
         # try:
@@ -129,7 +130,8 @@ class WBaseObj(QtWidgets.QTabWidget):
                 # self.insertTab(0, w_plain_text, "View")
 
         if self.count() == 0:
-            q_label = QtWidgets.QLabel("No graphs and reports.")
+            q_label = QtWidgets.QLabel(
+                f"No graphs or other information for '{obj.get_name():}'.")
             q_label.setSizePolicy(
                 QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding,
                                       QtWidgets.QSizePolicy.Expanding))
