@@ -88,14 +88,14 @@ class WFunction(QtWidgets.QFrame):
                                                     widget.checkState()//2))
                                 flag_special = True
                                 flag_label = False
-                            elif var_type is float:
-                                widget = QtWidgets.QDoubleSpinBox()
-                                widget.setValue(l_defaults[i_default])
-                                widget.attached_object = l_defaults[i_default]
-                                widget.valueChanged.connect(
-                                    lambda: setattr(widget, "attached_object",
-                                                    widget.value()))
-                                flag_special = True
+                            # elif var_type is float:
+                            #     widget = QtWidgets.QDoubleSpinBox()
+                            #     widget.setValue(l_defaults[i_default])
+                            #     widget.attached_object = l_defaults[i_default]
+                            #     widget.valueChanged.connect(
+                            #         lambda: setattr(widget, "attached_object",
+                            #                         widget.value()))
+                            #     flag_special = True
                             elif var_type is int:
                                 widget = QtWidgets.QSpinBox()
                                 widget.setValue(l_defaults[i_default])
