@@ -55,8 +55,8 @@ class WPanel(QtWidgets.QTreeWidget):
                                 Callable[[Any], Any]) -> NoReturn:
         """Set function when object is clicked."""
         self.func_object_clicked = func_object_clicked
-        # self.itemClicked.connect(func_object_clicked)
-        self.currentItemChanged.connect(func_object_clicked)
+        self.itemClicked.connect(func_object_clicked)
+        # self.currentItemChanged.connect(func_object_clicked)
 
     def dragEnterEvent(self, event):
         """Drag enter event."""
