@@ -5,7 +5,7 @@ from PyQt5 import QtWidgets, QtCore
 from cryspy import AtomSiteL, Crystal, Cell, SpaceGroup, \
     PdInstrResolution, Diffrn, \
     PdBackgroundL, Pd, PdMeasL, RhoChi, Chi2, \
-    Pd2dMeas, Pd2d, TOF, \
+    Pd2dMeas, Pd2dProc, Pd2d, TOF, \
     Setup, PhaseL, Range, DiffrnRadiation, Pd2dBackground, \
     Pd2dInstrResolution, DiffrnOrientMatrix, DiffrnReflnL, Phase, \
     AtomElectronConfigurationL, MEM, AtomSiteScatL, \
@@ -48,6 +48,10 @@ def define_tool_buttons(obj, thread: QtCore.QThread) -> tuple:
         w_actions = action_atom_site_scat_l(obj, thread)
     elif isinstance(obj, PdInstrResolution):
         w_actions = action_pd_instr_resolution(obj, thread)
+    elif isinstance(obj, Pd2dMeas):
+        w_actions = action_pd2d_meas(obj, thread)
+    elif isinstance(obj, Pd2dProc):
+        w_actions = action_pd2d_proc(obj, thread)
     elif isinstance(obj, Cell):
         w_actions = action_cell(obj, thread)
     elif isinstance(obj, SpaceGroup):
@@ -60,9 +64,9 @@ def define_tool_buttons(obj, thread: QtCore.QThread) -> tuple:
         w_actions = action_atom_site_l(obj, thread)
     elif isinstance(obj, InversedHessian):
         w_actions = action_inversed_hessian(obj, thread)
-    l_action = list(w_actions)
-    l_action.extend(action_plots(obj))
-    return tuple(l_action)
+    # l_action = list(w_actions)
+    # l_action.extend(action_plots(obj))
+    return w_actions
 
 
 def action_atom_site_l(obj: AtomSiteL, thread: QtCore.QThread):
@@ -715,6 +719,7 @@ def action_pd2d(obj: Pd2d, thread: QtCore.QThread):
     """Actions for pd2d."""
     w_actions = []
     f_meas = obj.is_attribute("pd2d_meas")
+    f_proc = obj.is_attribute("pd2d_proc")
     f_chi2 = obj.is_attribute("chi2")
     f_phase = obj.is_attribute("phase")
 
@@ -774,6 +779,66 @@ def action_pd2d(obj: Pd2d, thread: QtCore.QThread):
                 ttheta_min=4., ttheta_max=80., phi_min=-10., phi_max=20.)],
                 thread))
             w_actions.append(qtb_1)
+    if (f_proc | f_meas):
+        if f_proc:
+            w_actions.extend(action_pd2d_proc(obj.pd2d_proc, thread))
+        elif f_meas:
+            w_actions.extend(action_pd2d_proc(obj.pd2d_meas, thread))
+
+    return w_actions
+
+
+def action_pd2d_meas(obj: Pd2dMeas, thread: QtCore.QThread):
+    """Actions for Pd2dMeas objects."""
+    w_actions = []
+    qtb_1 = QtWidgets.QToolButton()
+    qtb_1.setText("Plot gamma-nu")
+
+    def func_plot_gn(obj):
+        fig, ax = obj.plot_gamma_nu()
+        fig.show()
+        return (fig, ax)
+
+    qtb_1.clicked.connect(lambda: func_plot_gn(obj))
+    w_actions.append(qtb_1)
+
+    qtb_1 = QtWidgets.QToolButton()
+    qtb_1.setText("Plot 2theta-phi")
+
+    def func_plot_tp(obj):
+        fig, ax = obj.plot_ttheta_phi()
+        fig.show()
+        return (fig, ax)
+
+    qtb_1.clicked.connect(lambda: func_plot_tp(obj))
+    w_actions.append(qtb_1)
+    return w_actions
+
+
+def action_pd2d_proc(obj: Pd2dProc, thread: QtCore.QThread):
+    """Actions for Pd2dMeas objects."""
+    w_actions = []
+    qtb_1 = QtWidgets.QToolButton()
+    qtb_1.setText("Plot gamma-nu")
+
+    def func_plot_gn(obj):
+        fig, ax = obj.plot_gamma_nu()
+        fig.show()
+        return (fig, ax)
+
+    qtb_1.clicked.connect(lambda: func_plot_gn(obj))
+    w_actions.append(qtb_1)
+
+    qtb_1 = QtWidgets.QToolButton()
+    qtb_1.setText("Plot 2theta-phi")
+
+    def func_plot_tp(obj):
+        fig, ax = obj.plot_ttheta_phi()
+        fig.show()
+        return (fig, ax)
+
+    qtb_1.clicked.connect(lambda: func_plot_tp(obj))
+    w_actions.append(qtb_1)
     return w_actions
 
 
